"""Initialize the translator method t from the given configuration file."""

# Built-ins
from typing import Callable

# Anint
from .constants import AnintDict
from .config import data
from .models import Translator
from . import translations

# Populate translations with the given absolute path.
translations.load(data[AnintDict.PATH])

# Initialize the method with the given values from the configuration file is any.
t: Callable[[str], str] = Translator(
    data[AnintDict.LOCALES],
    data[AnintDict.LOCALE],
    data[AnintDict.FALLBACKS],
).translate



"""Utility functions for Anint."""

# Built-ins
from re import split
from os.path import splitext
from typing import Union


def parse_key(key: str) -> list[str]:
    """Break up key into a list seperated by dots.

    :param str key: The key string.
    :return: A list of key values.
    """
    return split(r"\.", key)


def get_file_extension(filepath: str) -> str:
    """Extract the file extension from a given filepath.

    :param filepath: Specified file path.
    :return: Extension of the filepath.
    """
    return splitext(filepath)[1][1:]


def csv_to_list(list_string: Union[str, list]) -> list[str]:
    """Convert a comma separated string to a list of strings.

    :param list_string: A string of comma separated values.
    :return: A list of strings.
    """
    # If the input is a list, then return it as is.
    # Kinda hacky, but it works for data fetched from both toml and ini files.
    if isinstance(list_string, list):
        return list_string

    return [element.strip() for element in list_string.split(",")]



"""Anint: Ankha's Internationalization and Localization for Python."""

__all__: list[str] = [
    "t",
    "Translator",
    "TranslationError",
    "AnintConfigError",
    "MultipleSameLocaleError",
    "translations",
]

from .setup import t
from .models import Translator
from .exceptions import TranslationError, AnintConfigError, MultipleSameLocaleError
from . import translations



"""Exceptions for Anint."""

# Built-ins
from typing import Optional


class TranslationError(ValueError):
    """Missing or invalid translation."""

    def __init__(
        self, key: Optional[str], override_warning: Optional[str] = None
    ) -> None:
        """Create and return a new TranslationError instance."""
        if not override_warning:
            override_warning = "{key} is not a invalid translation key.".format(key=key)

        super(TranslationError, self).__init__(override_warning)


class AnintConfigError(RuntimeError):
    """Invalid configuration."""


class MultipleSameLocaleError(RuntimeError):
    """Multiple files with the same locale."""
